@@ -116,6 +116,7 @@ from ..kython.klogging import setup_logger, LazyLogger
 
 Paths = Union[Sequence[PathIsh], PathIsh]
 
+# TODO support '' for emtpy path
 DEFAULT_GLOB = '*'
 def get_files(pp: Paths, glob: str=DEFAULT_GLOB, sort: bool=True) -> Tuple[Path, ...]:
     """
@@ -124,11 +125,16 @@ def get_files(pp: Paths, glob: str=DEFAULT_GLOB, sort: bool=True) -> Tuple[Path,
     Tuple as return type is a bit friendlier for hashing/caching, so hopefully makes sense
     """
     # TODO FIXME mm, some wrapper to assert iterator isn't empty?
-    sources: List[Path] = []
-    if isinstance(pp, (str, Path)):
-        sources.append(Path(pp))
+    sources: List[Path]
+    if isinstance(pp, Path):
+        sources = [pp]
+    elif isinstance(pp, str):
+        if pp == '':
+            # special case -- makes sense for optional data sources, etc
+            return () # early return to prevent warnings etc
+        sources = [Path(pp)]
     else:
-        sources.extend(map(Path, pp))
+        sources = [Path(p) for p in pp]
 
     def caller() -> str:
         import traceback
@@ -332,3 +338,30 @@ def warn_if_empty(f):
         res = f(*args, **kwargs)
         return _warn_iterable(res, f=f)
     return wrapped # type: ignore
+
+
+# hacky hook to speed up for 'hpi doctor'
+# todo think about something better
+QUICK_STATS = False
+
+
+C = TypeVar('C')
+# todo not sure about return type...
+def stat(func: Callable[[], Iterable[C]]) -> Dict[str, Any]:
+    from more_itertools import ilen, take, first
+
+    it = iter(func())
+    res: Any
+    if QUICK_STATS:
+        initial = take(100, it)
+        res = len(initial)
+        if first(it, None) is not None: # todo can actually be none...
+            # haven't exhausted
+            res = f'{res}+'
+    else:
+        res = ilen(it)
+
+
+    return {
+        func.__name__: res,
+    }
